<?php

	if (!defined('IN_PARTS')) {
		exit;
	}


	class Url {
		private $url = '';
		private $params = array();

		private function appendParam(&$url, $name, $value) {
			if (isset($this->params[$name])) {
				/* Find and replace the current value */
				$start = strpos($url, '&' . $name . '=');
				$stop = strpos($url, '&', $start + 1);

				if ($stop === false) {
					$tail = '';
				}
				else {
					$tail = substr($url, $stop);
				}

				if ($value === NULL) {
					$url =
						substr($url, 0, $start) .
						$tail;
				}
				else {
					$url =
						substr($url, 0, $start + 1) .
						$name . '=' . urlencode($value) .
						$tail;
				}
			}
			elseif ($value !== NULL) {
				/* Just append it */
				$url .= '&' . $name . '=' . urlencode($value);
			}
		}

		public function set() {
			$nparams = func_num_args();

			for ($i = 0; $i < $nparams; $i += 2) {
				$name = func_get_arg($i);
				$value = func_get_arg($i + 1);

				$this->appendParam($this->url, $name, $value);
				$this->params[$name] = $value;
			}
		}

		public function deset() {
			$nparams = func_num_args();

			for ($i = 0; $i < $nparams; $i++) {
				$name = func_get_arg($i);

				if (!isset($this->params[$name])) {
					continue;
				}

				unset($this->params[$name]);

				$start = strpos($this->url, '&' . $name . '=');
				$stop = strpos($this->url, '&', $start + 1);

				if ($stop === false) {
					$tail = '';
				}
				else {
					$tail = substr($url, $stop);
				}

				$this->url = substr($this->url, 0, $start) . $tail;
			}
		}

		public function has($name) {
			return isset($this->params[$name]);
		}

		public function get($name) {
			return $this->params[$name];
		}


		public function build() {
			global $Action, $Tpl;

			$nparams = func_num_args();
			if ( ($nparams % 2) == 0 ) {
				$temp_action = $Action;
				$param = 0;
			}
			else {
				$temp_action = func_get_arg(0);
				$param = 1;
			}

			$temp_url = $this->url;
			for (; $param < $nparams; $param += 2) {
				$name = func_get_arg($param);
				$value = func_get_arg($param + 1);

				$this->appendParam($temp_url, $name, $value);
			}

			return 'index.php?ac=' . $temp_action . $temp_url;
		}


		public function buildBase() {
			global $Action, $Tpl;

			$nparams = func_num_args();
			if ( ($nparams % 2) == 0 ) {
				$temp_action = $Action;
				$param = 0;
			}
			else {
				$temp_action = func_get_arg(0);
				$param = 1;
			}

			$temp_url = '';
			for (; $param < $nparams; $param += 2) {
				$name = func_get_arg($param);
				$value = func_get_arg($param + 1);

				$temp_url .= '&' . $name . '=' . urlencode($value);
			}

			return 'index.php?ac=' . $temp_action . $temp_url;
		}

/*
		public function buildForm($excluded_group = NULL) {
			global $Action, $Tpl;

			$form = '<input type="hidden" name="ac" value="' .
				$Action . '" />';

			foreach ($this->params as $name => $value) {
				if (!isset($this->groups[$excluded_group][$name])) {
					$form .= '<input type="hidden" name="' . $name . '" value="' .
						$Tpl->escape($value) . '" />';
				}
			}

			return $form;
		}*/
	}



	function param($name) {
		if (isset($_GET[$name])) {
			return $_GET[$name];
		}
		elseif (isset($_POST[$name])) {
			return $_POST[$name];
		}
		else {
			return NULL;
		}
	}



	define('DEC_GERMAN', 0);
	define('DEC_ENGLISH', 1);

	function parse_decimal($string, $type = DEC_GERMAN) {
		switch ($type) {
			case DEC_GERMAN:
				/* Using the current locale */
				$string = str_replace('.', '', $string);
				$string = str_replace(',', '.', $string);
				return floatval($string);

			case DEC_ENGLISH:
				$string = str_replace(',', '', $string);
				return floatval($string);
		}
	}

	function format_decimal($number, $decimals = NULL) {
		if ($decimals === NULL) {
			return strval($number);
		}
		else {
			return strval(round($number, $decimals));
		}
	}

	function format_date($date) {
		return $date;
	}



	function calculate_magnitude(&$value, $base = 1000) {
		static $magnitudes = array(
			'a', 'f', 'p', 'n', 'u', 'm',
			'',
			'k', 'M', 'G', 'T', 'P', 'E'
		);

		if ($value == 0.0) {
			return '';
		}

		/* Scale it */
		$magnitude = floor(log(abs($value), $base));

		if (abs($magnitude) == 0) {
			return '';
		}

		/* Clamp base */
		if ($magnitude > 6) {
			$magnitude = 6;
		}
		elseif ($magnitude < -6) {
			$magnitude = -6;
		}

		$value *= pow($base, (-1) * $magnitude);
		$magnitude += 6;

		return $magnitudes[$magnitude];
	}





	function keysprintf($str, $args) {
		$result = '';
		$start = 0;

		while ( ($stop = strpos($str, '%', $start)) !== false ) {
			/* Append leading part */
			$result .= substr($str, $start, $stop - $start);
			$stop++;


			if (!isset($str{$stop})) {
				/* Missing key */
				return $result;
			}
			else {
				if ($str{$stop} == '%') {
					$result .= '%';
				}
				elseif (!isset($args[$str{$stop}])) {
					/* Unknown key */
					$result .= '?';
				}
				else {
					$result .= $args[$str{$stop}];
				}

				$stop++;
			}

			$start = $stop;
		}

		/* Append rest */
		$result .= substr($str, $start);
		return $result;
	}






	function urlfilesize($url, &$length, $ttl = 5) {
		$host = NULL;

		while ($ttl > 0) {
			$parsed_url = parse_url($url);

			if (!isset($parsed_url['host'])) {
				/* Seems to be a local URL */
				if ($host === NULL) {
					return false;
				}
			}
			else {
				$host = $parsed_url['host'];
			}

			/* Connect to remote server */
			if ( ($f = @fsockopen($host, 80, $errno, $errstr, 20)) === false ) {
				return false;
			}

			/* Send request */
			if (@fputs($f,
				"HEAD {$url} HTTP/1.1\r\n" .
				"Host: {$host}\r\n" .
				"Connection: close\r\n\r\n") === false) {

				@fclose($f);
				return false;
			}

			/* Parse response */
			while (!@feof($f)) {
				if ( ($header = @fgets($f, 65535)) === false ) {
					@fclose($f);
					return false;
				}


				if (preg_match('/^HTTP\\/[0-9]\\.[0-9]\\s+404/i', $header)) {
					@fclose($f);
					return false;
				}

				if (strtolower(substr($header, 0, 9)) == 'location:') {
					@fclose($f);

					/* Follow redirect */
					$url = trim(substr($header, 9));
					$ttl--;
					break;
				}

				if (strtolower(substr($header, 0, 15)) == 'content-length:') {
					@fclose($f);

					/* Found it */
					$length = intval(trim(substr($header, 15)));
					return true;
				}
			} /* while(!feof) */

			/* Ok but no content-length given */
			$length = NULL;
			return true;
		}

		return false;
	} /* function */

?>