<?php

	if (!defined('IN_PARTS')) {
		die('Hacking attempt.');
	}



	class ResistorColourParameter extends Parameter {
		private $sql_tolerance;


		public function __construct($name) {
			parent::__construct($name, 'Farbcode');
		}


		protected function createFilters() {
			/* vakat */
		}

		public function editable() {
			return false;
		}

		public function sortable() {
			return false;
		}


		public function setTolerance($tolerance) {
			$this->sql_tolerance = $tolerance;
		}

		public function tolerance() {
			return $this->sql_tolerance;
		}


		public function buildSql() {
			return
				$this->term() . ' AS `Pv_' . $this->name . '`, ' .
				$this->tolerance() . ' AS `Pt_' . $this->name . '`';
		}


		public function sqlFormat($value) {
			/* vakat */
		}

		protected function parse($string, &$value) {
			/* vakat */
		}


		private function findTolerance($t) {
			static $tolerances = array(
				-2 => 10,
				-1 => 5,
				1 => 1,
				2 => 2,
				5 => 0.5,
				6 => 0.25,
				7 => 0.1
			);

			if ($t > 10) {
				return NULL;
			}

			foreach ($tolerances as $ring => $tolerance) {
				if (abs($tolerance - $t) < 0.1) {
					return $ring;
				}
			}
		}


		public function sqlParse($row) {
			global $Db;

			$value = $Db->parseDecimal($row['Pv_' . $this->name]);

			if ($value == 0.0) {
				return array(array(0), NULL);
			}


			$tolerance = $Db->parseDecimal($row['Pt_' . $this->name]);
			$result = array(array());

			/* Store tolerance ring */
			$result[1] = $this->findTolerance($tolerance);

			/* Calculate value rings and multiplicator */
			if ($tolerance > 1) {
				$rings = 2;
			}
			elseif ($tolerance > 0.25) {
				$rings = 3;
			}
			else {
				$rings = 4;
			}


			$value_str = sprintf('%u', $value);
			for ($i = 0; ($i < $rings) && ($i < strlen($value_str)); $i++) {
				$result[0][] = intval($value_str[$i]);
			}

			for (; $i < $rings; $i++) {
				$result[0][] = 0;
			}


			/* See how many decimals are left or missing */
			$result[0][] = strlen($value_str) - $rings;

			return $result;
		}

		protected function format($value) {
/*			static $html_rings = array(
				'cad0ca', 'c5c070',
				'000000', '804000', 'ff0000', 'ff8000', 'ffff00',
				'00ff00', '0000ff', '800080', '808080', 'ffffff'
			);*/

			static $text_rings = array(
				'go', 'si',
				'sw', 'bn', 'rt', 'or', 'ge',
				'gn', 'bl', 'vi', 'gr', 'wß',
			);

/*			if ($fancy) {
				$result = '<span class="resistor">';

				foreach ($value[0] as $ring) {
					$result .= '<span style="background-color: #' .
						$html_rings[$ring + 2] . '">&#160;&#160;</span>' .
					'&#160;';
				}

				$result .= '&#160;';
				if ($value[1] === NULL) {
					$result .= '<span class="sblank">&#160;&#160;&#160;</span>';
				}
				else {
					$result .= '<span style="background-color: #' .
						$html_rings[$value[1] + 2] . '">&#160;&#160;&#160;</span>';
				}

				$result .= '</span>';
			}
			else {*/
				$result = '';

				foreach ($value[0] as $ring) {
					$result .= (($result == '') ? '' : '-') .
						$text_rings[$ring + 2];
				}

				if ($value[1] !== NULL) {
					$result .= '-' . $text_rings[$value[1] + 2];
				}
/*			}*/

			return $result;
		}
	}




	class ResistorModule extends Module {
		private $arguments;

		public function __construct($arguments) {
			$this->arguments = $arguments;

			$p = new DecimalParameter('value', 'Wert');
			$p->setSuffixes('Ω', 'Ohm'); /* Unicode */
			$p->setTerm('V_value');
			$p->setEditable(true);
			$this->addParameter($p);

			$p = new ResistorColourParameter('color_code');
			$p->setTerm('V_value');
			$p->setTolerance('V_tolerance');
			$this->addParameter($p);

			$p = new DecimalParameter('tolerance', 'Toleranz');
			$p->setSuffixes('%', 'Prozent');
			$p->setTerm('V_tolerance');
			$p->setEditable(true);
			$this->addParameter($p);

			$p = new DecimalRangeParameter('tolerance_range',
				"Toleranzbereich", 3);
			$p->setSuffixes('Ω', 'Ohm'); /* Unicode */
			$p->setTerm('V_value');
			$p->setTolerance('V_tolerance');
			$this->addParameter($p);

			$p = new DecimalParameter('power', 'Leistung');
			$p->setSuffixes('W', 'Watt');
			$p->setTerm('V_power');
			$p->setEditable(true);
			$this->addParameter($p);

			$p = new StringParameter('model', 'Gehäuse');
			$p->setTerm('V_model');
			$p->setEditable(true);
			$this->addParameter($p);
		}

		public function buildSqlConditions() {
			return '';
		}
	}


?>