<?php

	if (!defined('IN_PARTS')) {
		exit;
	}


	/* Try to identify model or category */
	$creating = false;
	if ( ($part_id = param('id')) !== NULL ) {
		$part_id = intval($part_id);

		/* Find module */
		$rs = $db->query(<<<ENDSQL
SELECT
	c.module,
	c.module_arguments,
	c.title,
	c.id,
	p.rohs,
	s.part_id AS `stock_part_id`
FROM
	`parts` p
	INNER JOIN `categories` c
		ON c.id = p.category_id
	LEFT JOIN `stock` s
		ON s.part_id = p.id
WHERE
	p.id = {$part_id}
LIMIT 1
ENDSQL
		);
	}
	elseif ( ($category_id = param('cat')) !== NULL ) {
		$creating = true;

		$category_id = intval($category_id);

		/* Fetch category information */
		$rs = $db->query(<<<ENDSQL
SELECT
	c.module,
	c.module_arguments,
	c.title,
	c.id
FROM
	`categories` c
WHERE
	c.id = {$category_id}
LIMIT 1
ENDSQL
		);
	}
	else {
		message('info',
			'Kein Modell zur Bearbeitung angegeben.',
			'stock'
		);
		return;
	}

	$category = $db->fetch($rs);
	$db->free($rs);


	if ($category === false) {
		message('alert',
			'Das Bauteil oder die Kategorie existiert nicht.',
			'stock'
		);
		return;
	}


	$module = Module::instance($category['module'], $category['module_arguments']);

	if ( ($sql_module_columns = $module->buildSqlColumns()) != '' ) {
		$sql_module_columns = ', ' . $sql_module_columns;
	}

	$sql_models_table = $module->buildSqlTable();


	if ($creating) {
		$url->set('cat', $category['id']);
	}
	else {
		/* Find model */
		$rs = $db->query(<<<ENDSQL
SELECT
	m.id
	{$sql_module_columns}
FROM
	{$sql_models_table} m
WHERE
	m.id = {$part_id}
LIMIT 1
ENDSQL
		);

		$model = $db->fetch($rs);
		$db->free($rs);

		if ($model === false) {
			message('alert',
				'Der zum Bauteil gehörende Modelldatensatz existiert nicht oder nicht mehr.',
				'Zurück zum Lager', $url->buildBase('stock', 'cat', $category['id'])
			);
			return;
		}

		$url->set('id', $part_id);
	}
?>

<div class="title"><img alt="Lager" src="images/16-part.png" />
<?php
	echo htmlspecialchars($category['title']) . ' &mdash; ' .
		(($creating) ? 'Neues Modell' : 'Bearbeiten');
?>
</div>


<?php
	if (isset($_POST['drop']) && !$creating) {
		if ($category['stock_part_id'] === NULL) {
			/* Delete part */
			$db->query("DELETE FROM `parts` WHERE `id` = {$part_id} LIMIT 1");

			/* Delete model */
			$db->query("DELETE FROM {$sql_models_table} WHERE `id` = {$part_id} LIMIT 1");

			/* Delete attachments */
			$db->query("DELETE FROM `attachments` WHERE `part_id` = {$part_id}");

			message('info',
				'Bauteil gelöscht.',
				'Zurück zum Lager', $url->buildBase('stock', 'cat', $category['id'])
			);

			return;
		}
	} /* if (isset($_POST['drop'])) */
?>


<div class="cobox">
	<div class="title">
		<img alt="Bauteilparameter" src="images/16-details.png" />
		Bauteilparameter</div>

<form action="index.php" method="post">
	<table style="width: 100%;">
		<tr>
			<th></th>

<?php
	if (!$creating) {
		if (isset($_POST['update'])) {
			echo '<th>Alter Wert</th>';
		}
		elseif (isset($_POST['copy'])) {
			echo '<th>Wert des Originalbauteils</th>';
		}
		else {
			echo '<th>Aktueller Wert</th>';
		}
	}
?>

			<th>Neuer Wert</th>
		</tr>

<?php
	/* Display model parameters */
	$update_parameters = array();
	$num_editables = 0;

	foreach ($module->parameters() as $parameter_name => $parameter) {
		echo '<tr><th>' . $parameter->title(true) . '</th>';
		if (!$creating) {
			echo '<td>' . $parameter->formatField($model, true) . '</td>';
		}

		if (!$parameter->editable()) {
			echo '<td /></tr>';
			continue;
		}

		$num_editables++;
		echo '<td>';
		echo '<input type="text" size="30" name="P' . $parameter_name . '"';

		if ( isset($_POST['update']) && isset($_POST['P' . $parameter_name]) ) {
			$value = $_POST['P' . $parameter_name];

			$parsed_value = NULL;
			if ($parameter->parseValue($value, $parsed_value)) {
				echo ' value="' . htmlspecialchars($parameter->formatValue($parsed_value)) . '"';
				$update_parameters[$parameter_name] = $parsed_value;
			}
			else {
				echo ' class="fail" value="' . htmlspecialchars($value) . '"';
			}
		}
		elseif (!$creating) {
			echo ' value="' . htmlspecialchars($parameter->formatField($model)) . '"';
		}

		echo ' />';

		if ($parameter->hasSuffix()) {
			echo ' (' . $parameter->suffix(true) . ')';
		}
		echo '</td></tr>';
	}
?>

		<tr>
			<th><img alt="RoHS-konform" src="images/rohs.png" /></th>

<?php
	if (!$creating) {
		$rohs = $category['rohs'];
		echo '<td>';
		if ($rohs === NULL) {
			echo 'Status unbekannt';
		}
		else {
			echo (($rohs == 'yes') ? 'konform' : 'nicht konform');
		}
		echo '</td>';
	}
	else {
		$rohs = NULL;
	}

	echo '<td>';
	echo '<input type="radio" id="Yrohs" name="rohs" value="y"' .
		(($rohs === 'yes') ? ' checked="checked"' : '') . ' />';
	echo '<label for="Yrohs">RoHS-konform</label><br />';

	echo '<input type="radio" id="Nrohs" name="rohs" value="n"' .
		(($rohs === 'no') ? ' checked="checked"' : '') . ' />';
	echo '<label for="Nrohs">nicht RoHS-konform</label><br />';

	echo '<input type="radio" id="Urohs" name="rohs" value="u"' .
		(($rohs === NULL) ? ' checked="checked"' : '') . ' />';
	echo '<label for="Urohs">Status unbekannt</label>';

	echo '</td>';
?>

		</tr>
	</table>

	<table class="form">

<?php
	$created_part_id = NULL;
	if (isset($_POST['update'])) {
		if (count($update_parameters) < $num_editables) {
			table_message('alert',
				'Die Änderungen wurden nicht übernommen;' .
				' bitte prüfen Sie Ihre Eingaben zu den hervorgehobenen Parametern.'
			);
		}
		else {
			/* Find RoHS */
			if (isset($_POST['rohs'])) {
				switch ($_POST['rohs']) {
					case 'y':
						$rohs = '\'yes\''; break;

					case 'n':
						$rohs = '\'no\''; break;

					case 'u':
					default:
						$rohs = 'NULL'; break;
				}
			}
			else {
				$rohs = 'NULL';
			}


			/* $sql_models_table from the beginning */
			if ($creating || isset($_POST['copy'])) {
				/* First generate part and obtain its ID */
				$db->query('INSERT INTO `parts` (`category_id`, `rohs`)' .
					" VALUES ({$category['id']}, {$rohs})");

				$created_part_id = $db->id();

				$sql = "INSERT INTO {$sql_models_table} (`id`";

				/* Column list */
				foreach ($module->parameters() as $parameter_name => $parameter) {
					if (!$parameter->editable()) {
						continue;
					}

					$sql .=  ', ' . $parameter->term();
				}

				$sql .= ") VALUES ({$created_part_id}";

				/* Value list */
				foreach ($module->parameters() as $parameter_name => $parameter) {
					if (!$parameter->editable()) {
						continue;
					}

					$sql .= ', ' .
						$parameter->sqlFormat($update_parameters[$parameter_name]);
				}

				$sql .= ')';
				$db->query($sql);


				if (!$creating && isset($_POST['copy_resources'])) {
					/* Attach resources */
					$rs = $db->query('SELECT a.resource_id FROM `attachments` a' .
						" WHERE a.part_id = {$part_id}");

					if (!$db->void($rs)) {
						$sql = 'INSERT INTO `attachments` (`part_id`, `resource_id`) VALUES';
						while ( ($resource = $db->fetch($rs)) !== false ) {
							$sql .= " ({$created_part_id}, {$resource['resource_id']}),";
						}

						$db->query(substr($sql, 0, -1));
					}

					$db->free($rs);
				}
			}
			else {
				$sql = '';
				foreach ($module->parameters() as $parameter_name => $parameter) {
					if (!$parameter->editable()) {
						continue;
					}

					$sql .= ', ' . $parameter->term() . ' = ' .
						$parameter->sqlFormat($update_parameters[$parameter_name]);
				}

				$db->query("UPDATE {$sql_models_table} m SET" . substr($sql, 1) .
					" WHERE m.id = {$part_id} LIMIT 1");

				$db->query("UPDATE `parts` p SET p.rohs = {$rohs}" .
					" WHERE p.id = {$part_id} LIMIT 1");
			}

			table_message('info',
				'Die Parameter wurden übernommen.'
			);
		}
	} /* if (isset($_POST['update'])) */
?>

		<tr>
			<th />
			<td>
				<input name="update" type="submit" value="Übernehmen" />
				<input type="reset" value="Zurücksetzen" />

<?php
	if ($creating || isset($_POST['copy'])) {
		if ($created_part_id !== NULL) {
			echo '<a href="' .
				$url->buildBase('part', 'id', $created_part_id) . '">Zum Bauteil</a>';
		}
	}
	else {
		if ($category['stock_part_id'] === NULL) {
			echo '<input name="drop" type="submit" value="Löschen" class="drop" />';
		}

		echo '<a href="' . $url->build('part') . '">Zurück zum Bauteil</a>';
	}

	echo ' oder <a href="' . $url->buildBase('stock', 'cat', $category['id']) . '">zum Lager</a>';

	if (!$creating) {
		echo '<br /><input name="copy" id="copy" type="checkbox" ' .
			((isset($_POST['copy'])) ? 'checked="checked"' : '') . ' />';
		echo '<label for="copy">Als Kopie übernehmen</label><br />';

		echo '<input name="copy_resources" id="copy_resources" type="checkbox" ' .
			((isset($_POST['copy_resources'])) ? 'checked="checked"' : '') . ' />';
		echo '<label for="copy_resources">Resourcen zur Kopie übernehmen</label><br />';
	}

	echo $url->buildForm();
?>

			</td>
		</tr>
	</table>

</form>
</div>

