<?php

	if (!defined('IN_PARTS')) {
		exit;
	}


	function build_category_tree($category_id) {
		global $Db, $Tpl, $Url;

		/* Obtain categories */
		$rs = $Db->query(<<<ENDSQL
SELECT
	c.left_id, c.right_id,
	c.title,
	c.id,
	c.module,
	c.module_arguments
FROM
	`categories` c
ORDER BY
	c.left_id
ENDSQL
		);

		/* Skip root and build tree */
		$row = $Db->fetch($rs);
		$last_level = $row['right_id'];
		$depth = 0;
		$category = NULL;

		/* Print tree */
		echo '<categories>';

		while ($row = $Db->fetch($rs)) {
			if ( ($row['left_id'] - $last_level) > 1 ) {
				echo '</category>';
				$depth--;
			}

			echo '<category' .
				' href="' . $Tpl->escape($Url->build('cat', $row['id'])) . '"';

			if ($row['module'] !== NULL) {
				echo ' id="' . $row['id'] . '"';

				if ($row['id'] == $category_id) {
					$root = 0;
					$category = $row;
				}
			}

			echo ' title="' . $Tpl->escape($row['title']) . '">';

			if ( ($row['right_id'] - $row['left_id']) == 1 ) {
				echo '</category>';
			}
			else {
				$depth++;
			}

			$last_level = $row['right_id'];
		}
		$Db->free($rs);

		while ($depth--) {
			echo '</category>';
		}

		echo '</categories>';
		return $category;
	}




	function build_order(&$sql_order) {
		global $module, $Tpl;

		$order_param = NULL;
		$sql_order = '';
		if (isset($_GET['ord'])) {
			$order_param = substr($_GET['ord'], 1);

			if ($module->hasParameter($order_param) &&
					$module->parameter($order_param)->sortable()) {

				if (strtoupper(substr($_GET['ord'], 0, 1)) == 'A') {
					$order_dir = 'ASC';
				}
				else {
					$order_dir = 'DESC';
				}

				$sql_order = ' ORDER BY ' .
					$module->parameter($order_param)->buildSqlSort() .
					' ' . $order_dir;

				echo ' order-by="' . $Tpl->escape($order_param) . '"';
				echo ' order-dir="' . $order_dir . '"';
			}
			else {
				$order_param = NULL;
			}
		}
	}


	function build_display(&$sql_stock, &$sql_display) {
		global $User;

		if (isset($_GET['stock'])) {
			$sql_stock = ' INNER JOIN';
			echo ' only-stock="only-stock"';
		}
		else {
			$sql_stock = ' LEFT JOIN';
		}

		$sql_stock .= ' `stock` s ON s.part_id = p.id' .
				' AND s.user_id = ' .$User['id'];

		$sql_display = '';
		if (isset($_GET['rohs'])) {
			$sql_display .= ' AND `rohs` = \'yes\'';
			echo ' only-rohs="only-rohs"';
		}

		if (isset($_GET['Nsmd'])) {
			$sql_display .= ' AND `technology` <> \'smd\'';
			echo ' no-smd="no-smd"';
		}

		if (isset($_GET['Ntht'])) {
			$sql_display .= ' AND `technology` <> \'tht\'';
			echo ' no-tht="no-tht"';
		}
	}


	function build_suppliers(&$sql_suppliers) {
		global $Db, $Tpl;

		$sql_suppliers = '';
		$rs = $Db->query('SELECT s.id, s.title FROM `suppliers` s' .
			' ORDER BY title ASC');

		$suppliers = array();
		while ( ($supplier = $Db->fetch($rs)) !== false ) {
			if (!isset($_GET['S']) && isset($_GET['S' . $supplier['id']])) {
				$sql_suppliers .= ', ' . $supplier['id'];
				$flag = true;
			}
			else {
				$flag = false;
			}

			$suppliers[$supplier['id']] = array(
				$supplier['title'],
				$flag
			);
		}

		$Db->free($rs);

		if ($sql_suppliers != '') {
			$sql_suppliers =
				' INNER JOIN `prices` pr ON pr.part_id = p.id AND' .
				' pr.supplier_id IN (' . substr($sql_suppliers, 2) . ')';
		}

		echo '<suppliers>';
		foreach ($suppliers as $id => $supplier) {
			echo '<supplier id="' . $id . '"';
			if ($supplier[1]) {
				echo ' select="select"';
			}
			echo '>' . $Tpl->escape($supplier[0]) . '</supplier>';
		}
		echo '</suppliers>';
	}


	function build_parametric($parameter_name, $parameter) {
		echo '<parametric';

		$current_filter_arguments = 0;
		if (!isset($_GET['detach'])) {
			/* Get current filter mode */
			if (isset($_GET['P' . $parameter_name])) {
				$current_filter_name = $_GET['P' . $parameter_name];

				if (!$parameter->hasFilter($current_filter_name)) {
					$current_filter_name = '';
				}
			}
			else {
				$current_filter_name = '';
			}


			/* Try to parse necessary arguments */
			if ($current_filter_name != '') {
				$current_filter = $parameter->filter($current_filter_name);

				$current_filter_arguments = $current_filter->numArguments();
				for ($i = 0; $i < $current_filter_arguments; $i++) {
					$argument_name = 'P' . ($i + 1) . $parameter_name;

					if (!isset($_GET[$argument_name])) {
						break;
					}

					if (!$current_filter->parseArgument($i, $_GET[$argument_name])) {
						break;
					}
				}

				if ($i != $current_filter_arguments) {
					/* Failed to parse all necessary arguments */
					$current_filter_name = '';
					$current_filter_arguments = 0;
				}
				else {
					/* Use filter */
					echo ' filter="' . $current_filter_name . '"';
					$current_filter->activate();
				}
			}
		}

		echo '>'; /* <parametric...> */

		/* List filter modes */
		foreach ($parameter->filters() as $filter_name => $filter) {
			echo '<filter id="' . $filter_name . '">' .
				$filter->title() . '</filter>';
		}


		/* Generate input fields */
		for ($i = 0; $i < $parameter->maxNumArguments(); $i++) {
			echo '<argument>';
			if ($i < $current_filter_arguments) {
				echo $current_filter->formatArgument($i);
			}
			echo '</argument>';
		}

		echo '</parametric>';
	}


	function build_pagination(&$sql_pagination, &$page_start) {
		if (isset($_GET['st'])) {
			$page_start = max(1, intval($_GET['st']));
		}
		else {
			$page_start = 1;
		}

		$sql_pagination = ' LIMIT ' .
			(($page_start - 1) * CF_PER_PAGE) . ', ' . (CF_PER_PAGE + 1);
	}



	if ( ($category_id = param('cat')) !== NULL ) {
		$category_id = abs(intval($category_id));
	}
	else {
		$category_id = 0;
	}

	$category = build_category_tree($category_id);



	if ( ($category === NULL) || ($category['module'] === NULL) ) {
		echo '<message type="information">Bitte wählen Sie eine Kategorie.</message>';
	}
	else {
		$Url->set('cat', $category['id']);

		/* Load render module */
		require 'module.php';
		$module = Module::instance($category['module'], $category['module_arguments']);


		/* Menu */
		echo '<link' .
			' id="new-model"' .
			' href="' . $Tpl->escape($Url->buildBase('edit-model', 'cat', $category['id'])) . '">' .
			'Neues Modell</link>';


		build_pagination($sql_pagination, $page_start);

		echo '<parts' .
			' page="' . $page_start . '"' .
			' base-href="' . $Tpl->escape($Url->buildBase('part', 'id', '')) . '"' .
			' category="' . $category['id'] . '"';

		build_order($sql_order);
		build_display($sql_stock, $sql_display);

		echo '>'; /* <parts ... > */

		build_suppliers($sql_suppliers);

		/* Show or hide columns */
		echo '<columns' .
			' base-href="' . $Tpl->escape($Url->build()) . '">';
		$hidden_parameters = array();
		foreach ($module->parameters() as $parameter_name => $parameter) {
			/* Hide or display columns */
			echo '<column' .
				' id="' . $parameter_name . '"' .
				' title="' . $Tpl->escape($parameter->title()) . '"';


			if ($parameter->sortable()) {
				echo ' sortable="sortable"';
			}

			if (isset($_GET['H' . $parameter_name]) && !isset($_GET['uH'])) {
				echo ' hidden="hidden"';
				$hidden_parameters[] = $parameter_name;
			}

			echo '>';


			/* Add parametric stuff */
			if ($parameter->hasFilters()) {
				build_parametric($parameter_name, $parameter);
			}

			echo '</column>';
		}
		echo '</columns>';



		/* Build SQL statement */
		if ( ($sql_module_columns = $module->buildSqlColumns()) != '' ) {
			$sql_module_columns = ', ' . $sql_module_columns;
		}

		if ( ($sql_module_filter = $module->buildSqlFilters()) != '' ) {
			$sql_module_filter = ' AND ' . $sql_module_filter;
		}

		if ( ($sql_conditions = $module->buildSqlConditions()) != '' ) {
			$sql_conditions = ' AND ' . $sql_conditions;
		}

		$sql_models_table = $module->buildSqlTable();

		$rs = $Db->query(<<<ENDSQL
SELECT
	p.id,
	p.rohs,
	SUM(s.quantity) AS `quantity`
	{$sql_module_columns}
FROM
	`parts` p
	INNER JOIN {$sql_models_table} m
		ON m.id = p.id
	{$sql_suppliers}
	{$sql_stock}
WHERE
	1
	{$sql_module_filter}
	{$sql_conditions}
	{$sql_display}
GROUP BY
	p.id
{$sql_order}
{$sql_pagination}
ENDSQL
		);


		/* Display records */
		$row_count = 0;
		while ( ($row_count < CF_PER_PAGE) && ($row = $Db->fetch($rs)) ) {
			$row_count++;

			/* Private data */
			echo '<part' .
				' id="' . $row['id'] . '"';

			if ($row['quantity'] > 0) {
				echo ' stock="' . $row['quantity'] . '"';
			}

			if ($row['rohs'] !== NULL) {
				echo ' rohs="' . (($row['rohs'] == 'yes') ? 'y' : 'n') . '"';
			}

			echo '>'; /* <part...> */


			/* Parametric fields */
			foreach ($module->parameters() as $parameter_name => $parameter) {
				if (in_array($parameter_name, $hidden_parameters)) {
					continue;
				}

				/* Format data */
				echo '<p>';
				echo $Tpl->escape($parameter->formatField($row));
				echo '</p>';
			}

			echo '</part>';
		}

		echo '</parts>';
	}

	$Tpl->render('stock.xsl');
?>