<?php

	if (!defined('IN_PARTS')) {
		exit;
	}

	/*
		As of 7 January 2009

		Amazon REST documentation:
			http://developer.amazonwebservices.com/connect/entry.jspa?categoryID=12&externalID=627

		Including Amazon's ID 0JE9C2T2RN684MDM6G02

		OfferSummary description:
			http://docs.amazonwebservices.com/AWSEcommerceService/2007-01-17/ApiReference/OfferSummaryResponseGroup.html


		REST Brokers:
			CA http://ecs.amazonaws.ca/onca/xml?Service=AWSECommerceService
			DE http://ecs.amazonaws.de/onca/xml?Service=AWSECommerceService
			FR http://ecs.amazonaws.fr/onca/xml?Service=AWSECommerceService
			JP http://ecs.amazonaws.jp/onca/xml?Service=AWSECommerceService
			UK http://ecs.amazonaws.co.uk/onca/xml?Service=AWSECommerceService
			US http://ecs.amazonaws.com/onca/xml?Service=AWSECommerceService


		Readable article page is at:
			http://www.amazon.de/gp/product/<ARTNO>

	*/


	class AmazonSupplier extends Supplier {
		private static $AccessKeyID = '0JE9C2T2RN684MDM6G02';
		private static $XMLNamespace = 'http://webservices.amazon.com/AWSECommerceService/2005-10-05';


		private static function findPrice(&$prices, $root, &$total, $type, $title) {
			$items = $root->getElementsByTagName('Lowest' . $type . 'Price');
			if ($items->length == 0) {
				return false;
			}

			$item = $items->item(0);
			$amount = $item->getElementsByTagName('Amount');
			$currency = $item->getElementsByTagName('CurrencyCode');

			if ( ($amount->length == 0) || ($currency->length == 0) ) {
				return false;
			}

			$total_nodes = $root->getElementsByTagName('Total' . $type);
			if ($total_nodes->length == 1) {
				$total += intval(
					parse_decimal($total_nodes->item(0)->nodeValue, DEC_GERMAN)
				);
			}

			$prices[] = array(
				$title,
				parse_decimal($amount->item(0)->nodeValue, DEC_GERMAN) / 100.0,
				trim($currency->item(0)->nodeValue),
			);
		}

		private function fromASIN($asin) {
			$xml = file_get_contents(
				'http://ecs.amazonaws.de/onca/xml' .
				'?Service=AWSECommerceService' .
				'&AWSAccessKeyId=' . self::$AccessKeyID .
				'&Operation=ItemLookup' .
				'&ItemId=' . $asin .
				'&ResponseGroup=OfferSummary'
			);

			if ($xml === false) {
				return false;
			}


			$dom = new DOMDocument();
			if (!@$dom->loadXML($xml)) {
				return false;
			}

			$xpath = new DOMXpath($dom);
			$xpath->registerNamespace(
				'aws',
				self::$XMLNamespace
			);


			/* Check validity of request */
			$nodes = $xpath->query(
				'/aws:ItemLookupResponse/aws:Items/aws:Request/aws:IsValid'
			);

			if (($nodes->length == 0) ||
					($nodes->item(0)->nodeValue != 'True')) {
				return false;
			}


			/* Get pricing node */
			$nodes = $xpath->query(
				'/aws:ItemLookupResponse/aws:Items/aws:Item'
			);

			if ($nodes->length == 0) {
				return false;
			}

			$pricing_node = $nodes->item(0);


			/* New articles */
			$prices = array();
			$total = 0;
			self::findPrice($prices, $pricing_node, $total,
				'New', 'neu');
			self::findPrice($prices, $pricing_node, $total,
				'Used', 'gebraucht');
			self::findPrice($prices, $pricing_node, $total,
				'Collectible', 'Sammlerstück');
			self::findPrice($prices, $pricing_node, $total,
				'Refurbished', 'restauriert');


			if (count($prices) == 0) {
				return false;
			}

			return array(
				'quantity' => $total,
				'prices' => $prices
			);
		}



		public function findPrices($code) {
			return $this->fromASIN($code);
		}

		public function formatCode($code, $html = false) {
			return $this->artcode;
		}

		public function buildLink($code) {
			return 'http://www.amazon.de/gp/product/' . $code;
		}
	}


?>