<?php

	if (!defined('IN_PARTS')) {
		exit;
	}

/*
	As of 5 January 2009.

	Example: Article code = 18891

	Articles are at:
		http://www.reichelt.de/?;
			ACTION=3;
			LA=4;
			GROUP=A425;
			GROUPID=2996;
			ARTICLE=18891;
			START=0;
			SORT=user;
			OFFSET=76;
			SID=26B01o76wQARoAAFezUYs4d0688fb98d37c2c54db1c5c59853308


	Shortest possible URL is:
		http://www.reichelt.de/?;ARTICLE=18891


	Price is best parsed from the print version at
		http://www.reichelt.de/?
			IW=1;
			ACTION=503;
			ARTICLE=18891;
			GROUPID=2996;

	Shortest version:
		http://www.reichelt.de/?ACTION=503;ARTICLE=18891
*/


	class ReicheltSupplier {
		private $prices;
		private $artno;

		private function __construct($artno, $prices) {
			$this->artno = $artno;
			$this->price = $prices;
		}



		private function fromArtNo($artno) {
			$html = @file_get_contents(
				'http://www.reichelt.de/?ACTION=503;ARTICLE=' . $artno);

			if ($html === false) {
				return false;
			}


			$html = str_replace('reichelt elektronik GmbH & Co', '', $html);

			/* Try to find pricing */
			$doc = new DOMDocument();
			if (!$doc->loadHTML($html)) {
				return false;
			}


			/*
				Note that loadHTML won't create nodes for XHTML stuff
				such as tbody.
			*/
			$xpath = new DOMXpath($doc);
			$nodes = $xpath->query(
				'/html/body/div[3]/div/table/tr/td/table' .
				'/tr[2]/td/table/tr/td[2]/h3/span'
			);

			if ($nodes->length == 0) {
				return false;
			}


			$node = $nodes->item(0);
			$raw = $node->nodeValue;

			/* Parse value */
			$raw = str_replace(',', '.', $raw);

			$result = preg_match(
				'/(([0-9][\\.])?[0-9]+)/is',
				$raw,
				$matches
			);

			if (!$result) {
				return false;
			}

			return new ReicheltSupplier(
				$artno,
				array(1 => floatval($matches[1]))
			);
		}

		public function create($code) {
			if (is_numeric($code)) {
				return self::fromArtNo($code);
			}
			else {
				return self::fromArtKey($code);
			}
		}



		public function prices() {
			return $this->prices;
		}

		public function buildLink() {
			return 'http://www.reichelt.de/?;ARTICLE=' . $this->artno;
		}
	}


?>