<?php

	if (!defined('IN_PARTS')) {
		exit;
	}


	abstract class Template {
		protected $xml;

		public function __construct() {
			ob_start();
		}

		public function escape($s) {
			return htmlspecialchars($s);
		}


		protected abstract function transform($template);

		protected function send($content) {
			echo $content;
		}

		public function render($template) {
			global $Action;

			$this->xml =
				'<template id="' . $this->escape($Action) . '">' .
				ob_get_contents() .
				'</template>';

			ob_end_clean();

			$content = $this->transform($template);
			$this->send($content);
		}
	}




	class ClientXSLTemplate extends Template {
		protected function transform($template) {
			/* Important for Firefox and such */
			header('Content-Type: text/xml');


			$xslt = 'templates/default/' . $template;

			return
				'<?xml version="1.0" encoding="utf-8"?>' .
				'<?xml-stylesheet version="1.0" encoding="utf-8" type="text/xml" href="' .
					htmlspecialchars($xslt) . '" ?>' .
				$this->xml;
		}
	}


	class ServerXSLTemplate extends Template {
		private $processor = '/usr/bin/xsltproc --nomkdir --nonet --nowrite --encoding "utf-8" --xinclude -';

		protected function transform($template) {
			global $Action;

			/* Pipe to XSL processor */
			$descriptors = array();
			$process = proc_open(
				$this->processor,
				array(
					0 => array('pipe', 'r'),
					1 => array('pipe', 'w'),
					2 => array('pipe', 'w')
				),
				$descriptors,
				NULL
			);

			$stdin = $descriptors[0];
			$stdout = $descriptors[1];
			$stderr = $descriptors[2];


			/* Write input to processor */
			$xslt = 'templates/default/' . $template;

			fwrite($stdin,
				'<?xml version="1.0" encoding="utf-8"?>' .
				'<?xml-stylesheet version="1.0" encoding="utf-8" type="text/xml" href="' .
					htmlspecialchars($xslt) . '" ?>'
			);
			fwrite($stdin, $this->xml);
			fclose($stdin);

			/* Retrieve result */
			$html = stream_get_contents($stdout);
			fclose($stdout);
			$error = stream_get_contents($stderr);
			fclose($stderr);


			/* Retrieve exit status */
			$timeout = 10;
			while ($timeout > 0) {
				$status = proc_get_status($process);
				if ($status['running']) {
					$timeout--;
					usleep(1000 * 100);
				}
				else {
					break;
				}
			}

			if ( ($timeout == 0) || ($status['exitcode'] != 0) ) {
				echo '<pre>' . htmlspecialchars($error).'</pre>';
				die('Bad XSLT processor (code ' . $status['exitcode'] . ').');
			}

			proc_close($process);

			return $html;
		}

	}

?>