<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

<xsl:output
	encoding="utf-8"
	indent="no"
	method="xml"
	omit-xml-declaration="no"
	version="1.0"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1.dtd" />

<xsl:template match="/template">
	<html xmlns="http://www.w3.org/1999/xhtml">
		<head>
			<link rel="stylesheet" href="templates/default/images/main.css" type="text/css" />
			<meta http-equiv="content-type" content="text/html; charset=utf-8" />
			<title>PartsDB &#8212; <xsl:value-of select="$title" /></title>
		</head>

		<body>
			<xsl:call-template name="body" />

			<div id="footer">
				<xsl:value-of select="date" /> &#8226; PartsDB v0.1
			</div>
		</body>
	</html>
</xsl:template>


<xsl:template name="fancy-body">
	<div id="frame">
		<div id="header">
			PartsDB

			<div id="navigation">
				<xsl:apply-templates select="/template/link" />
				<xsl:if test="/template/link"> &#8212; </xsl:if>

				<a><xsl:attribute name="href"><xsl:value-of select="/template/toolbar/link[@id='index']" /></xsl:attribute>Übersicht</a>
				&#8226;
				<a><xsl:attribute name="href"><xsl:value-of select="/template/toolbar/link[@id='stock']" /></xsl:attribute>Lager</a>
				&#8226;
				<a><xsl:attribute name="href"><xsl:value-of select="/template/toolbar/link[@id='logout']" /></xsl:attribute>Logout</a>
			</div>
		</div>

		<xsl:call-template name="content" />

		<br style="clear: both;" />
	</div>
</xsl:template>




<xsl:template match="message">
	<table style="margin: auto;">
		<tr>

			<td style="vertical-align: middle; width: 32px;">
				<img>
					<xsl:choose>
						<xsl:when test="@type = 'information'">
							<xsl:attribute name="alt">Information</xsl:attribute>
							<xsl:attribute name="src">templates/default/images/128-info.png</xsl:attribute>
						</xsl:when>
						<xsl:when test="@type = 'alert'">
							<xsl:attribute name="alt">Hinweis</xsl:attribute>
							<xsl:attribute name="src">templates/default/images/128-warning.png</xsl:attribute>
						</xsl:when>
					</xsl:choose>
				</img>
			</td>

			<td style="vertical-align: middle;">
				<xsl:value-of select="." />
				<br />
				<strong>Was möchten Sie tun?</strong>
				<ul>
					<li>
						<a><xsl:attribute name="href"><xsl:value-of select="/template/toolbar/link[@id='index']" /></xsl:attribute>Zur Übersicht gehen</a>
					</li>
				</ul>
			</td>

		</tr>
	</table>
</xsl:template>



<xsl:template name="pagination-page">
	<xsl:param name="page" select="1" />
	<xsl:param name="current-page" select="1" />

	<xsl:if test="$page &gt; 1">, </xsl:if>

	<xsl:choose>
		<xsl:when test="$page = $current-page">
			<strong><xsl:value-of select="$page" /></strong>
		</xsl:when>
		<xsl:when test="($page = 4) and ($current-page &gt; 6)">
			&#8230;
			<xsl:call-template name="pagination-page">
				<xsl:with-param name="page" select="$current-page - 2" />
				<xsl:with-param name="current-page" select="$current-page" />
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$current-page != $page">
			<a>
				<xsl:call-template name="url">
					<xsl:with-param name="append" select="concat('&amp;st=', $page)" />
				</xsl:call-template>

				<xsl:if test="$current-page = $page">
					<xsl:attribute name="style">font-weight: bold;</xsl:attribute>
				</xsl:if>

				<xsl:value-of select="$page" />
			</a>

			<xsl:call-template name="pagination-page">
				<xsl:with-param name="page" select="$page + 1" />
				<xsl:with-param name="current-page" select="$current-page" />
			</xsl:call-template>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="pagination">
	<xsl:param name="page" />

	<div class="pagination">
		Seite:
		<xsl:call-template name="pagination-page">
			<xsl:with-param name="current-page" select="$page" />
		</xsl:call-template>,

		<a>
			<xsl:call-template name="url">
				<xsl:with-param name="append" select="concat('&amp;st=', $page + 1)" />
			</xsl:call-template>
			Nächste
		</a>
	</div>
<!--
for ($i = 0; $i <= $page_start; $i++) {
		if ($page_start == $i) {
			echo '<strong>' . ($i + 1) . '</strong> ';
		}
		else {
			echo '<a href="' . $url->build('st', $i) . '">' .
				($i + 1) . '</a> ';
		}

		if ( ($i == 2) && (($page_start - $i) > 2) )  {
			echo ' &hellip; ';
			$i = $page_start-3;
		}
	}


	/* Link to next page if possible */
	if ( ($row_count == CF_PER_PAGE) && (db_fetch($rs) !== false) ) {
		$page_start++;
		echo '<a href="' . $url->build('st', $page_start) . '">' .
			($page_start + 1) . ' &raquo;</a>';
	}
	echo '';

	$Db->free($rs);

	}
-->




</xsl:template>


</xsl:stylesheet>
