<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">

<xsl:variable name="title">Lager</xsl:variable>

<xsl:include href="base.xsl" />

<xsl:template name="body">
	<xsl:call-template name="fancy-body" />
</xsl:template>


<xsl:template match="/template/link">
	<a>
		<xsl:attribute name="href"><xsl:value-of select="@href" /></xsl:attribute>
		<img>
			<xsl:attribute name="alt"><xsl:value-of select="." /></xsl:attribute>
			<xsl:attribute name="title"><xsl:value-of select="." /></xsl:attribute>
			<xsl:attribute name="src">templates/default/images/<xsl:choose><xsl:when test="@id = 'new-model'">16-new.png</xsl:when></xsl:choose></xsl:attribute>
		</img>
	</a>
</xsl:template>


<xsl:template match="/template/categories//category">
	<xsl:choose>

		<xsl:when test="count(./category) &gt; 0">
			<li><xsl:value-of select="@title" />
				<ul>
					<xsl:apply-templates select="./category" />
				</ul>
			</li>
		</xsl:when>

		<xsl:otherwise>
			<li>
				<xsl:if test="/template/parts/@category = @id">
					<xsl:attribute name="style">font-weight: bold;</xsl:attribute>
				</xsl:if>

				<xsl:choose>
					<xsl:when test="@id">
						<a><xsl:attribute name="href"><xsl:value-of select="@href" /></xsl:attribute><xsl:value-of select="@title" /></a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@title" />
					</xsl:otherwise>
				</xsl:choose>
			</li>
		</xsl:otherwise>

	</xsl:choose>
</xsl:template>



<xsl:template match="/template/parts/columns/column/parametric">
	<tr>
		<td><xsl:value-of select="../@title" /></td>
		<td>
			<select size="1">
				<xsl:attribute name="name">P<xsl:value-of select="../@id" /></xsl:attribute>
				<option value="">
					<xsl:if test="not(@filter)">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					-----
				</option>

				<xsl:for-each select="filter">
					<option>
						<xsl:if test="../@filter = @id">
							<xsl:attribute name="selected">selected</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="value"><xsl:value-of select="@id" /></xsl:attribute>
						<xsl:value-of select="." />
					</option>
				</xsl:for-each>
			</select>
		</td>

		<td>
			<xsl:for-each select="argument">
				<input type="text" size="10">
					<xsl:attribute name="name"><xsl:value-of select="concat('P', position(), ../../@id)" /></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="." /></xsl:attribute>
				</input>
			</xsl:for-each>
			</td>
	</tr>
</xsl:template>



<xsl:template match="template/parts/part">
	<tr>
		<xsl:choose>
			<xsl:when test="(position() mod 2) = 0">
				<xsl:attribute name="class">even</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="class">odd</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>

		<td>
			<a>
				<xsl:attribute name="href"><xsl:value-of select="concat(/template/parts/@base-href, @id)" /></xsl:attribute>
				<img alt="Details" src="templates/default/images/16-part.png" />
			</a>
		</td>
		<td class="pri"><xsl:value-of select="@stock" /></td>
		<td>
			<xsl:if test="@rohs">
				<img>
					<xsl:choose>
						<xsl:when test="@rohs = 'y'">
							<xsl:attribute name="src">templates/default/images/16-rohs.png</xsl:attribute>
							<xsl:attribute name="alt">RoHS-konform</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="src">templates/default/images/16-norohs.png</xsl:attribute>
							<xsl:attribute name="alt">nicht RoHS-konform</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</img>
			</xsl:if>
		</td>

		<xsl:for-each select="p">
			<td>
				<xsl:value-of select="." />
			</td>
		</xsl:for-each>
	</tr>
</xsl:template>




<!-- Flagbag for URLs -->
<xsl:template name="url">
	<xsl:param name="ord" select="concat(substring(/template/parts/@order-dir, 1, 1), /template/parts/@order-by)" />

	<xsl:param name="unhide" />
	<xsl:param name="unhide-all" />
	<xsl:param name="hide" />

	<xsl:param name="append" />

	<xsl:attribute name="href"><xsl:value-of select="/template/parts/columns/@base-href" /><xsl:if test="$hide"><xsl:value-of select="concat('&amp;H', $hide, '=y')" /></xsl:if><xsl:if test="$ord">&amp;ord=<xsl:value-of select="$ord" /></xsl:if><xsl:if test="not($unhide-all)"><xsl:for-each select="/template/parts/columns/column[@hidden and (@id != $unhide)]">&amp;H<xsl:value-of select="@id" />=y</xsl:for-each></xsl:if><xsl:if test="/template/parts[@only-stock]">&amp;stock=y</xsl:if><xsl:if test="/template/parts[@only-rohs]">&amp;rohs=y</xsl:if><xsl:if test="/template/parts[@no-smd]">&amp;Nsmd=y</xsl:if><xsl:if test="/template/parts[@no-tht]">&amp;Ntht=y</xsl:if><xsl:if test="/template/parts/suppliers/supplier[not(@select)]"><xsl:for-each select="/template/parts/suppliers/supplier[@select]"><xsl:value-of select="concat('&amp;S', @id, '=y')" /></xsl:for-each></xsl:if><xsl:for-each select="/template/parts/columns/column/parametric"><xsl:if test="@filter"><xsl:value-of select="concat('&amp;P', ../@id, '=', @filter)" /><xsl:for-each select="argument"><xsl:value-of select="concat('&amp;P', position(), ../../@id, '=', .)" /></xsl:for-each></xsl:if></xsl:for-each><xsl:value-of select="$append" /></xsl:attribute>
</xsl:template>

<!-- Dito, for forms -->
<xsl:template name="display-form">
	<input type="hidden" name="ac" value="stock" />
	<input type="hidden" name="cat">
		<xsl:attribute name="value"><xsl:value-of select="/template/parts/@category" /></xsl:attribute>
	</input>

	<xsl:if test="/template/parts/@order-by"><input type="hidden" name="ord">
		<xsl:attribute name="value"><xsl:value-of select="concat(substring(/template/parts/@order-dir, 1, 1), /template/parts/@order-by)" /></xsl:attribute>
	</input></xsl:if>

	<xsl:for-each select="/template/parts/columns/column[@hidden]">
		<input type="hidden" value="y">
			<xsl:attribute name="name">H<xsl:value-of select="@id" /></xsl:attribute>
		</input>
	</xsl:for-each>
</xsl:template>

<xsl:template name="filter-form">
	<xsl:if test="/template/parts[@only-stock]">
		<input type="hidden" name="stock" value="y" />
	</xsl:if>

	<xsl:if test="parts[@only-rohs]">
		<input type="hidden" name="rohs" value="y" />
	</xsl:if>

	<xsl:if test="parts[@no-smd]">
		<input type="hidden" name="Nsmd" value="y" />
	</xsl:if>

	<xsl:if test="parts[@no-tht]">
		<input type="hidden" name="Ntht" value="y" />
	</xsl:if>

	<xsl:if test="/template/parts/suppliers/supplier[not(@select)]">
		<xsl:for-each select="/template/parts/suppliers/supplier[@select]">
			<input type="hidden" value="y">
				<xsl:attribute name="name">S<xsl:value-of select="@id" /></xsl:attribute>
			</input>
		</xsl:for-each>
	</xsl:if>
</xsl:template>

<xsl:template name="parametric-form">
	<xsl:for-each select="parts/columns/column/parametric">
		<xsl:if test="@filter">
			<input type="hidden">
				<xsl:attribute name="name">P<xsl:value-of select="../@id" /></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@filter" /></xsl:attribute>
			</input>

			<xsl:for-each select="argument">
				<input type="hidden">
					<xsl:attribute name="name"><xsl:value-of select="concat('P', position(), ../../@id)" /></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="." /></xsl:attribute>
				</input>
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>
</xsl:template>



<xsl:template name="content">
	<div class="cobox" style="width: 25%; float: left;">
		<div class="title">
			<img alt="Bauteile" src="templates/default/images/16-stock.png" />Bauteile</div>

		<ul class="tree">
			<xsl:apply-templates select="categories/category" />
		</ul>
	</div>

	<xsl:apply-templates select="message" />

	<xsl:if test="parts">
		<xsl:if test="parts/columns/column/parametric">
			<div style="clear: right; width: 70%; float: right; overflow: scroll;">
				<form method="get">
					<xsl:attribute name="action"><xsl:value-of select="parts/columns/@base-href" /></xsl:attribute>
					<xsl:call-template name="display-form" />
					<xsl:call-template name="filter-form" />

					<table class="parametric" style="width: 100%">
						<tr><th colspan="3">Parametrisch</th></tr>

						<xsl:apply-templates select="parts/columns/column/parametric" />

						<tr>
							<td colspan="3" style="text-align: center;">
								<input type="submit" value="Anwenden" />
								<input type="reset" value="Zurücksetzen" />
								<input type="submit" name="detach" value="Lösen" />
							</td>
						</tr>
					</table>
				</form>
			</div>
		</xsl:if>

		<div style="clear: right; width: 70%; float: right; overflow: scroll;">
			<table class="catalog">
				<tr>
					<th style="width: 16px;"></th>
					<th class="pri">Menge</th>
					<th style="width: 16px;"></th>

					<xsl:for-each select="parts/columns/column[not(@hidden)]">
						<th>
							<xsl:value-of select="@title" />

							<xsl:if test="@sortable">
								<a>
									<xsl:choose>
										<xsl:when test="(@id = ../../@order-by) and (../../@order-dir = 'ASC')">
											<img src="templates/default/images/12-aup.png" alt="Aufwärts sortiert" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:call-template name="url">
												<xsl:with-param name="ord" select="concat('A', @id)" />
											</xsl:call-template>
											<img src="templates/default/images/10-up.png" alt="Aufwärts sortieren" />
										</xsl:otherwise>
									</xsl:choose>
								</a>

								<a>
									<xsl:choose>
										<xsl:when test="(@id = ../../@order-by) and (../../@order-dir = 'DESC')">
											<img src="templates/default/images/12-adown.png" alt="Abwärts sortiert" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:call-template name="url">
												<xsl:with-param name="ord" select="concat('D', @id)" />
											</xsl:call-template>
											<img src="templates/default/images/10-down.png" alt="Abwärts sortieren" />
										</xsl:otherwise>
									</xsl:choose>
								</a>
							</xsl:if>

							<a>
								<xsl:call-template name="url">
									<xsl:with-param name="hide" select="@id" />
								</xsl:call-template>
								<img src="templates/default/images/10-hide.png" alt="Verstecken" />
							</a>
						</th>
					</xsl:for-each>
				</tr>

				<xsl:apply-templates select="parts/part" />

			</table>

			<xsl:call-template name="pagination">
				<xsl:with-param name="page" select="parts/@page" />
			</xsl:call-template>
		</div>


		<xsl:if test="parts/columns/column[@hidden]">
			<div style="clear: right; width: 70%; float: right;">
				<p>Versteckte Spalten einblenden:
					<xsl:if test="count(parts/columns/column[@hidden]) &gt; 1">
						<a>
							<xsl:call-template name="url">
								<xsl:with-param name="unhide-all" select="'yes'" />
							</xsl:call-template>
							<strong>alle</strong>
						</a>,
					</xsl:if>

					<xsl:for-each select="parts/columns/column[@hidden]">
						<a>
							<xsl:call-template name="url">
								<xsl:with-param name="unhide" select="@id" />
							</xsl:call-template>
							<xsl:value-of select="@title"/>
						</a>
						<xsl:if test="position() &lt; last()">, </xsl:if>
					</xsl:for-each>
				</p>
			</div>
		</xsl:if>


		<div class="cobox" style="clear: right; width: 65%; float: right;">
			<div class="title">
				<img alt="Bauteile" src="templates/default/images/16-filter.png" />Filter</div>

			<form method="get">
				<xsl:attribute name="action"><xsl:value-of select="parts/columns/@base-href" /></xsl:attribute>
				<xsl:call-template name="display-form" />
				<xsl:call-template name="parametric-form" />

				<table width="100%">
					<tr>
						<th>Bauteiltyp</th>
						<th>Lieferanten</th>
					</tr>
					<tr>
						<td>
							<input type="checkbox" name="stock" id="stock" value="y">
								<xsl:if test="parts[@only-stock]"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							</input>
							<label for="stock">Nur Bauteile auf Lager</label><br />

							<input type="checkbox" name="rohs" id="rohs" value="y">
								<xsl:if test="parts[@only-rohs]"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							</input>
							<label for="rohs">Nur RoHS-konforme Bauteile</label><br />

							<input type="checkbox" name="Nsmd" id="Nsmd" value="y">
								<xsl:if test="parts[@no-smd]"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							</input>
							<label for="Nsmd">Keine SMD-Bauteile</label><br />

							<input type="checkbox" name="Ntht" id="Ntht" value="y">
								<xsl:if test="parts[@no-tht]"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							</input>
							<label for="Ntht">Keine bedrahteten Bauteile</label><br />
						</td>
						<td>
							<div style="overflow: scroll; width: 100%; height: 75px;">
								<xsl:for-each select="parts/suppliers/supplier">
									<input type="checkbox" value="y">
										<xsl:attribute name="name">S<xsl:value-of select="@id" /></xsl:attribute>
										<xsl:attribute name="id">S<xsl:value-of select="@id" /></xsl:attribute>
										<xsl:if test="@select"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
									</input>

									<label>
										<xsl:attribute name="for">S<xsl:value-of select="@id" /></xsl:attribute>
										<xsl:value-of select="." />
									</label><br />
								</xsl:for-each>
							</div>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<input type="submit" value="Anwenden" />
						</td>
					</tr>
				</table>
			</form>
		</div>

	</xsl:if>
</xsl:template>

</xsl:stylesheet>

